searchNodes=[{"doc":"The LiveSelect component is rendered by calling the live_select/1 function and passing it a form field. LiveSelect creates a text input field in which the user can type text, and hidden input field(s) that will contain the value of the selected option(s). Whenever the user types something in the text input, LiveSelect triggers a live_select_change event for your LiveView or LiveComponent. The message has a text parameter containing the current text entered by the user, as well as id and field parameters with the id of the LiveSelect component and the name of the LiveSelect form field, respectively. Your job is to handle the event, retrieve the list of selectable options and then call Phoenix.LiveView.send_update/3 to send the list of options to LiveSelect. See the &quot;Examples&quot; section below for details, and check out the cheatsheet for some useful tips. Selection can happen either using the keyboard, by navigating the options with the arrow keys and then pressing enter, or by clicking an option with the mouse. Whenever an option is selected, LiveSelect will trigger a standard phx-change event in the form. See the &quot;Examples&quot; section below for details on how to handle the event. In single mode, if the configuration option allow_clear is set, the user can manually clear the selection by clicking on the x button on the input field. In tags mode, single tags can be removed by clicking on them. Single mode Tags mode When :tags mode is enabled LiveSelect allows the user to select multiple entries. The entries will be visible above the text input field as removable tags. The selected entries will be passed to your live view's change and submit event handlers as a list of entries, just like an HTML &lt;select&gt; element with multiple attribute would do. Options You can pass or update the list of options the user can choose from with the options assign. Each option will be assigned a label, which will be shown in the dropdown, and a value, which will be the value of the LiveSelect input when the option is selected. options can be any enumeration of the following elements: atoms, strings or numbers : In this case, each element will be both label and value for the option tuples : {label, value} corresponding to label and value for the option maps : %{label: label, value: value} or %{value: value} keywords : [label: label, value: value] or [value: value] In the case of maps and keywords, if only value is specified, it will be used as both value and label for the option. Because you can pass a list of tuples, you can use maps and keyword lists to pass the list of options, for example: %{ Red : 1 , Yellow : 2 , Green : 3 } Will result in 3 options with labels :Red , :Yellow , :Green and values 1, 2, and 3. Note that the option values, if they are not strings, will be JSON-encoded. Your LiveView will receive this JSON-encoded version in the phx-change and phx-submit events. Styling LiveSelect supports 3 styling modes: tailwind : uses standard tailwind utility classes (the default) daisyui : uses daisyUI classes. none : no styling at all. Please see the styling section for details Alternative tag labels Sometimes, in :tags mode, you might want to use alternative labels for the tags. For example, you might want the labels in the tags to be shorter in order to save space. You can do this by specifying an additional tag_label key when passing options as map or keywords. For example, passing these options: [ %{ label : &quot;New York&quot; , tag_label : &quot;NY&quot; } , %{ label : &quot;Barcelona&quot; , tag_label : &quot;BCN&quot; } ] will result in &quot;New York&quot; and &quot;Barcelona&quot; being used for the options in the dropdown, while &quot;NY&quot; and &quot;BCN&quot; will be used for the tags. Slots You can control how your options and tags are rendered by using the :option and :tag slots. Let's say you want to show some fancy icons next to each option in the dropdown and the tags: &lt; . live_select field = { @form [ :city_search ] } phx - target = { @myself } mode = { :tags } &gt; &lt; :option :let = { option } &gt; &lt; div class = &quot;flex&quot; &gt; &lt; . globe / &gt; &amp; nbsp ; &lt; % = option . label % &gt; &lt; / div &gt; &lt; / :option &gt; &lt; :tag :let = { option } &gt; &lt; . check / &gt; &amp; nbsp ; &lt; % = option . label % &gt; &lt; / :tag &gt; &lt; / . live_select &gt; Here's the result: Controlling the selection programmatically You can always control the selection programmatically, overriding the current user-selected values, by sending a :value update to LiveSelect via Phoenix.LiveView.send_update/3 : send_update ( LiveSelect.Component , id : live_select_id , value : new_selection ) new_selection must be a single element in :single mode, a list in :tags mode. If it's nil , the selection will be cleared. After updating the selection, LiveSelect will trigger a change event in the form. To set a custom id for the component to use with Phoenix.LiveView.send_update/3 , you can pass the id assign to live_select/1 . Examples These examples describe all the moving parts in detail. You can see these examples in action, see which messages and events are being sent, and play around with the configuration easily with the showcase app . Single mode The user can search for cities. The LiveSelect main form input is called city_search . When a city is selected, the coordinates of that city will be the value of the form input. The name of the selected city is available in the text input field named city_search_text_input . Template: &lt; . form for = { @form } phx - change = &quot;change&quot; &gt; &lt; . live_select field = { @form [ :city_search ] } / &gt; &lt; / . form &gt; Forms implemented in LiveComponents If your form is implemented in a LiveComponent and not in a LiveView, you have to add the phx-target attribute when rendering LiveSelect: &lt; . live_select field = { @form [ :city_search ] } phx - target = { @myself } / &gt; LiveView or LiveComponent that is the target of the form's events: import LiveSelect @impl true def handle_event ( &quot;live_select_change&quot; , %{ &quot;text&quot; =&gt; text , &quot;id&quot; =&gt; live_select_id } , socket ) do cities = City . search ( text ) # cities could be: # [ {&quot;city name 1&quot;, [lat_1, long_1]}, {&quot;city name 2&quot;, [lat_2, long_2]}, ... ] # # but it could also be (no coordinates in this case): # [ &quot;city name 1&quot;, &quot;city name 2&quot;, ... ] # # or: # [ [label: &quot;city name 1&quot;, value: [lat_1, long_1]], [label: &quot;city name 2&quot;, value: [lat_2, long_2]], ... ] # # or even: # [&quot;city name 1&quot;: [lat_1, long_1], &quot;city name 2&quot;: [lat_2, long_2]] send_update ( LiveSelect.Component , id : live_select_id , options : cities ) { :noreply , socket } end @impl true def handle_event ( &quot;change&quot; , %{ &quot;my_form&quot; =&gt; %{ &quot;city_search_text_input&quot; =&gt; city_name , &quot;city_search&quot; =&gt; city_coords } } , socket ) do IO . puts ( &quot;You selected city \#{ city_name } located at: \#{ city_coords } &quot; ) { :noreply , socket } end Tags mode Let's say you want to build on the previous example and allow the user to select multiple cities and not only one. The :tags mode allows you to do exactly this. Template: &lt; . form for = { @form } phx - change = &quot;change&quot; &gt; &lt; . live_select field = { @form [ :city_search ] } mode = { :tags } / &gt; &lt; / . form &gt; LiveView or LiveComponent that is the target of the form's events: @impl true def handle_event ( &quot;change&quot; , %{ &quot;my_form&quot; =&gt; %{ &quot;city_search&quot; =&gt; list_of_coords } } , socket ) do # list_of_coords will contain the list of the JSON-encoded coordinates of the selected cities, for example: # [&quot;[-46.565,-23.69389]&quot;, &quot;[-48.27722,-18.91861]&quot;] IO . puts ( &quot;You selected cities located at: \#{ list_of_coords } &quot; ) { :noreply , socket } end Multiple LiveSelect inputs in the same LiveView If you have multiple LiveSelect inputs in the same LiveView, you can distinguish them based on the field id. For example: Template: &lt; . form for = { @form } phx - change = &quot;change&quot; &gt; &lt; . live_select field = { @form [ :city_search ] } / &gt; &lt; . live_select field = { @form [ :album_search ] } / &gt; &lt; / . form &gt; LiveView or LiveComponent: @impl true def handle_event ( &quot;live_select_change&quot; , %{ &quot;text&quot; =&gt; text , &quot;id&quot; =&gt; live_select_id , &quot;field&quot; =&gt; live_select_field } , socket ) do options = case live_select_field do &quot;form_name_city_search&quot; -&gt; City . search ( text ) &quot;form_name_album_search&quot; -&gt; Album . search ( text ) end send_update ( LiveSelect.Component , id : live_select_id , options : options ) { :noreply , socket } end","ref":"LiveSelect.html","title":"LiveSelect","type":"module"},{"doc":"Renders a LiveSelect input in a form. Attributes field ( :any ) (required) - a Phoenix.HTML.FormField struct identifying the form's field. id ( :string ) - an id to assign to the component. If none is provided, \#{form_name}_\#{field}_live_select_component will be used. mode ( :atom ) - either :single (for single selection), or :tags (for multiple selection using tags). Defaults to :single . options ( :list ) - initial available options to select from. See the &quot;Options&quot; section for details on what you can pass here. value ( :any ) - used to manually set a selection - overrides any values from the form. Must be a single element in :single mode, or a list of elements in :tags mode. max_selectable ( :integer ) - limits the maximum number of selectable elements. 0 means unlimited. Defaults to 0 . user_defined_options ( :boolean ) - if true , hitting enter will always add the text entered by the user to the selection. Defaults to false . allow_clear ( :boolean ) - if true , when in single mode, display a &quot;x&quot; button in the input field to clear the selection. disabled ( :boolean ) - set this to true to disable the input field. placeholder ( :string ) - placeholder text for the input field. debounce ( :integer ) - number of milliseconds to wait after the last keystroke before triggering a &quot;live_select_change&quot; event. Defaults to 100 . update_min_len ( :integer ) - the minimum length of text in the text input field that will trigger an update of the dropdown. Defaults to 1 . style ( :atom ) - one of :tailwind , :daisyui or :none . See the Styling section for details. Defaults to :tailwind . phx-target ( :any ) - Optional target for events. Usually the same target as the form's. phx-blur ( :string ) - Event to emit when the text input loses focus. The component id will be sent in the event's params. phx-focus ( :string ) - Event to emit when the text input receives focus. The component id will be sent in the event's params. Slots option - optional slot that renders an option in the dropdown. The option's data is available via :let . tag - optional slot that renders a tag. The option's data is available via :let . Styling attributes See the styling section for details","ref":"LiveSelect.html#live_select/1","title":"LiveSelect.live_select/1","type":"function"},{"doc":"The module that implements the LiveSelect live component","ref":"LiveSelect.Component.html","title":"LiveSelect.Component","type":"module"},{"doc":"","ref":"LiveSelect.Component.html#parent_event/3","title":"LiveSelect.Component.parent_event/3","type":"function"},{"doc":"Callback implementation for Phoenix.LiveComponent.render/1 .","ref":"LiveSelect.Component.html#render/1","title":"LiveSelect.Component.render/1","type":"function"},{"doc":"Dynamic (multi)selection field for LiveView. LiveSelect is a LiveView component that implements a dynamic selection field with a dropdown. The content of the dropdown is filled by your LiveView as the user types. This allows you to easily create an interface for search-like functionalities with type-ahead. LiveSelect s features include: Single as well as multiple selection Options to configure the behaviour, such as minimum number of characters that trigger an update or the maximum number of selectable options Default styles for daisyUI and tailwindcss, which are fully customizable and can be completely overriden if needed Ability to customize the rendered HTML for dropdown entries and tags using slots. Try it in the showcase app 🔬 Single selection (single mode) Multiple selection (tags mode)","ref":"readme.html","title":"Readme","type":"extras"},{"doc":"Template: &lt; . form for = { @form } phx - change = &quot;change&quot; &gt; &lt; . live_select field = { @form [ :city_search ] } / &gt; &lt; / . form &gt; NOTE: If your form is implemented in a LiveComponent, add phx-target={@myself} , like this: &lt; . live_select field = { @form [ :city_search ] } phx - target = { @myself } / &gt; In the LiveView or LiveComponent that's the target of your form events: import LiveSelect @impl true def handle_event ( &quot;live_select_change&quot; , %{ &quot;text&quot; =&gt; text , &quot;id&quot; =&gt; live_select_id } , socket ) do cities = City . search ( text ) # cities = [ # {&quot;New York City&quot;, [-74.00597,40.71427]}, # {&quot;New Kingston&quot;, [-76.78319,18.00747]}, # ... # ] send_update ( LiveSelect.Component , id : live_select_id , options : cities ) { :noreply , socket } end @impl true def handle_event ( &quot;change&quot; , %{ &quot;my_form&quot; =&gt; %{ &quot;city_search_text_input&quot; =&gt; city_name , &quot;city_search&quot; =&gt; city_coords } } , socket ) do IO . puts ( &quot;You selected city \#{ city_name } located at: \#{ city_coords } &quot; ) { :noreply , socket } end Refer to the module documentation for the details, and check out the cheatsheet for some useful tips.","ref":"readme.html#usage-example","title":"Readme - Usage Example 🧭","type":"extras"},{"doc":"To install, add this to your dependencies: [ { :live_select , &quot;~&gt; 1.0&quot; } ]","ref":"readme.html#installation","title":"Readme - Installation 📦","type":"extras"},{"doc":"LiveSelect relies on Javascript hooks to work. You need to add LiveSelect 's hooks to your live socket. LiveSelect distributes its Javascript code (a single file) in the same way as LiveView, by including an npm package as part of its hex package. To include LiveSelect 's hooks, add this to your app.js file: import live_select from &quot;live_select&quot; // if you don't have any other hooks: let liveSocket = new LiveSocket(&quot;/live&quot;, Socket, {params: {_csrf_token: csrfToken}, hooks: live_select}) // if you have other hooks: const hooks = { MyHook: { // ... }, ...live_select } let liveSocket = new LiveSocket(&quot;/live&quot;, Socket, {params: {_csrf_token: csrfToken}, hooks}) If you're using Webpack or another NPM-based builder If you're using an npm-based builder such as Webpack, you will need to add LiveSelect to the list of your dependencies in your package.json (just as you did with LiveView): { &quot;dependencies&quot;: { &quot;phoenix&quot;: &quot;file:../deps/phoenix&quot;, &quot;phoenix_html&quot;: &quot;file:../deps/phoenix_html&quot;, &quot;phoenix_live_view&quot;: &quot;file:../deps/phoenix_live_view&quot;, &quot;live_select&quot;: &quot;file:../deps/live_select&quot; // &lt;-- add this line, and add an extra &quot;../&quot; if you're in an umbrella app } } And then run npm install from your assets folder. You will also need to run npm install --force live_select whenever you update the LiveSelect hex package in order to get the latest JS code.","ref":"readme.html#javascript-hooks","title":"Readme - Javascript hooks 🪝","type":"extras"},{"doc":"LiveSelect supports 3 styling modes: tailwind : uses standard tailwind utility classes (the default) daisyui : uses daisyUI classes. none : no styling at all. The choice of style is controlled by the style option in live_select/1 . tailwind and daisyui styles come with sensible defaults which can be selectively extended or completely overridden. If you're using tailwind or daisyui styles, you need to add one of the following lines to the content section in your tailwind.config.js : module.exports = { content: [ //... '../deps/live_select/lib/live_select/component.*ex', // &lt;-- for a standalone app '../../../deps/live_select/lib/live_select/component.*ex' // &lt;-- for an umbrella app ] //.. } Notice the different paths for a standalone or umbrella app. Refer to the Styling section for further details.","ref":"readme.html#styling","title":"Readme - Styling 🎨","type":"extras"},{"doc":"The repository includes a showcase app that you can use to experiment with the different options and parameters for LiveSelect . The showcase app is available here . To start the showcase app locally, simply run: mix setup PORT = 4001 mix phx . server from within the cloned repository. The app will be available at http://localhost:4001 . The showcase app allows you to quickly experiment with options and styles, providing an easy way to fine tune your LiveSelect component. The app also shows the messages and events that your LiveView receives. For each event or message, the app shows the function head of the callback that your LiveView needs to implement in order to handle the event.","ref":"readme.html#showcase-app","title":"Readme - Showcase app 🎪","type":"extras"},{"doc":"Contributions are very welcome! Use mix test to run the entire test suite, which is subdivided into 3 main files: test/live_select/component_test.exs - everything that can be tested by rendering the component statically test/live_select_test.exs - tests for single mode that require a running LiveView test/live_select_tags_test.exs - tests for tags mode that require a running LiveView Tests that require a LiveView use the showcase app as the parent LiveView.","ref":"readme.html#contribute","title":"Readme - Contribute 🤝","type":"extras"},{"doc":"[X] Add package.json to enable import live_select from &quot;live_select&quot; [X] Make sure component classes are included by tailwind [X] Enable custom styling [X] Rename LiveSelect.render to live_select [X] Customizable placeholder [X] Enable configuration of styles in the showcase app [X] Add support for vanilla tailwind styles [X] Enable multiple selection mode [X] Expose as function component (and drop LV 0.17 support) [X] Add cheatsheet showing how to: [ ] Additional multiple selection mode","ref":"readme.html#roadmap","title":"Readme - Roadmap 🛣️","type":"extras"},{"doc":"LiveSelect supports 3 styling modes: tailwind : uses standard tailwind utility classes (the default) daisyui : uses daisyUI classes. none : no styling at all. The choice of style is controlled by the style option in live_select/1 . tailwind and daisyui styles come with sensible defaults which can be extended or overridden via options. This is what each default style looks like: daisyui: (the actual colors may differ depending on the selected daisyui theme ) tailwind: These defaults can be selectively overridden or extended using the appropriate options to live_select/1 . You can control the style of the following elements: The outer container of the live_select component The text input field The text input field when an option has been selected The dropdown that contains the selectable options The single selectable option (s) The currently active option Here's a visual representation of the elements: In tags mode there are 4 additional stylable elements: The tag showing the selected options The tags_container that contains the tags selected_option . This is an option in the dropdown that has already been selected. It's still visible, but can't be selected again available_option . This is an option in the dropdown that has not been selected and is available for selection For each of these elements there is an {element}_class and for some also an {element}_extra_class option, which can be used to override or extend the default CSS classes for the element, respectively. These options accept both strings and lists of strings. You can't use both options together: use {element}_class to completely override the default classes, or use {element}_extra_class to extend the default. The following table shows the default styles for each element and the options you can use to adjust its CSS classes. Element Default daisyui classes Default tailwind classes Class override option Class extend option active_option active bg-gray-600 text-white active_option_class available_option cursor-pointer cursor-pointer hover:bg-gray-400 rounded available_option_class container dropdown dropdown-open h-full relative text-black container_class container_extra_class dropdown bg-base-200 dropdown-content menu menu-compact p-1 rounded-box shadow w-full absolute bg-gray-100 rounded-md shadow w-full z-50 dropdown_class dropdown_extra_class option px-4 py-1 rounded option_class option_extra_class selected_option disabled text-gray-400 selected_option_class tag badge badge-primary p-1.5 text-sm bg-blue-400 flex p-1 rounded-lg text-sm tag_class tag_extra_class tags_container flex flex-wrap gap-1 p-1 flex flex-wrap gap-1 p-1 tags_container_class tags_container_extra_class text_input input input-bordered pr-6 w-full disabled:bg-gray-100 disabled:placeholder:text-gray-400 disabled:text-gray-400 pr-6 rounded-md w-full text_input_class text_input_extra_class text_input_selected input-primary border-gray-600 text-gray-600 text_input_selected_class For example, if you want to remove rounded borders from the options, have the active option use white text on a red background, and use green as a background color for tags instead of blue, render live_select/1 like this: &lt; . live_select form = { my_form } field = { my_field } id = &quot;live_select&quot; mode = { :tags } placeholder = &quot;Search for a city&quot; active_option_class = &quot;text-white bg-red-800&quot; option_extra_class = &quot;!rounded&quot; tag_extra_class = &quot;!bg-blue-400 bg-green-200&quot; / &gt; Selectively removing classes from defaults You can remove classes included with the style's defaults by using the !class_name notation in an {element}_extra_class option. For example, if a default style is rounded-lg px-4 , using an extra class option of !rounded-lg text-black will result in the following final class being applied to the element: px-4 text-black","ref":"styling.html","title":"Styling","type":"extras"},{"doc":"","ref":"cheatsheet.html","title":"Cheatsheet","type":"extras"},{"doc":"1. Add this to core_components.ex : def live_select ( %{ field : % Phoenix.HTML.FormField { } = field } = assigns ) do assigns = assign ( assigns , :errors , Enum . map ( field . errors , &amp; translate_error ( &amp;1 ) ) ) live_select_opts = assigns_to_attributes ( assigns , [ :errors , :label ] ) ~H&quot;&quot;&quot; &lt;div phx-feedback-for={@field.name}&gt; &lt;.label for={@field.id}&gt;&lt;%= @label %&gt;&lt;/.label&gt; &lt;LiveSelect.live_select field={@field} text_input_class={[ &quot;mt-2 block w-full rounded-lg border-zinc-300 py-[7px] px-[11px]&quot;, &quot;text-zinc-900 focus:outline-none focus:ring-4 sm:text-sm sm:leading-6&quot;, &quot;phx-no-feedback:border-zinc-300 phx-no-feedback:focus:border-zinc-400 phx-no-feedback:focus:ring-zinc-800/5&quot;, &quot;border-zinc-300 focus:border-zinc-400 focus:ring-zinc-800/5&quot;, @errors != [] &amp;&amp; &quot;border-rose-400 focus:border-rose-400 focus:ring-rose-400/10&quot; ]} {live_select_opts} /&gt; &lt;.error :for={msg &lt;- @errors}&gt;&lt;%= msg %&gt;&lt;/.error&gt; &lt;/div&gt; &quot;&quot;&quot; end 2. Then call it this way: &lt; . live_select field = { @form [ :city ] } label = &quot;City&quot; phx - target = { @myself } / &gt; You can also pass any of the other LiveSelect options.","ref":"cheatsheet.html#style-liveselect-like-a-phoenix-core-component-with-label-and-errors","title":"Cheatsheet - Style LiveSelect like a Phoenix Core Component, with label and errors","type":"extras"},{"doc":"1. With no options displayed if the user doesn't enter any text Heex template: &lt; . live_select field = { @form [ :locations ] } update_min_len = { 1 } phx - focus = &quot;clear&quot; / &gt; Live view: @impl true def handle_event ( &quot;live_select_change&quot; , %{ &quot;id&quot; =&gt; id , &quot;text&quot; =&gt; text } , socket ) do options = retrieve_locations ( ) |&gt; Enum . filter ( &amp; ( String . downcase ( &amp;1 ) |&gt; String . contains? ( String . downcase ( text ) ) ) ) send_update ( LiveSelect.Component , options : options , id : id ) { :noreply , socket } end @impl true def handle_event ( &quot;clear&quot; , %{ &quot;id&quot; =&gt; id } , socket ) do send_update ( LiveSelect.Component , options : [ ] , id : id ) { :noreply , socket } end 2. With a fixed set of default options to be displayed when the text input is empty Heex template: &lt; . live_select field = { @form [ :locations ] } update_min_len = { 0 } phx - focus = &quot;set-default&quot; options = { @default_locations } / &gt; Live view: @impl true def mount ( socket ) do socket = assign ( socket , default_locations : default_locations ( ) ) { :ok , socket } end @impl true def handle_event ( &quot;live_select_change&quot; , %{ &quot;id&quot; =&gt; id , &quot;text&quot; =&gt; text } , socket ) do options = if text == &quot;&quot; do socket . assigns . default_locations else retrieve_locations ( ) |&gt; Enum . filter ( &amp; ( String . downcase ( &amp;1 ) |&gt; String . contains? ( String . downcase ( text ) ) ) ) end send_update ( LiveSelect.Component , options : options , id : id ) { :noreply , socket } end @impl true def handle_event ( &quot;set-default&quot; , %{ &quot;id&quot; =&gt; id } , socket ) do send_update ( LiveSelect.Component , options : socket . assigns . default_locations , id : id ) { :noreply , socket } end","ref":"cheatsheet.html#implementing-a-simple-search-functionality","title":"Cheatsheet - Implementing a simple search functionality","type":"extras"},{"doc":"Heex template: &lt; . live_select field = { @form [ :my_field ] } mode = { :tags } container_extra_class = &quot;flex flex-col&quot; dropdown_extra_class = &quot;top-11&quot; tags_container_extra_class = &quot;order-last&quot; / &gt;","ref":"cheatsheet.html#display-tags-underneath-the-input-field-if-you-re-using-tailwind","title":"Cheatsheet - Display tags underneath the input field (if you're using tailwind)","type":"extras"},{"doc":"","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"add phx-focus and phx-blur options to specify events to be sent to the parent upon focus and blur of the text input field send live_select_change event directly from JS hook to save a round-trip expects a single field assign of type Phoenix.HTML.FormField instead of separate form and field assigns (which is still supported but soft-deprecated with a warning)","ref":"changelog.html#1-1-0-2023-06-26","title":"CHANGELOG - 1.1.0 (2023-06-26)","type":"extras"},{"doc":"Do not use name attribute on non-input elements to prevent LV from crashing Change default for update_min_len to 1","ref":"changelog.html#1-0-4-2023-05-30","title":"CHANGELOG - 1.0.4 (2023-05-30)","type":"extras"},{"doc":"Programmatically override selection with value assign Only clear options if entered text is shorter than update_min_len and user types backspace Bugfix: fix selection via mouseclick not working when rendering nested elements in the :option slot","ref":"changelog.html#1-0-3-2023-03-31","title":"CHANGELOG - 1.0.3 (2023-03-31)","type":"extras"},{"doc":"styling options now also accept lists of strings","ref":"changelog.html#1-0-2-2023-03-20","title":"CHANGELOG - 1.0.2 (2023-03-20)","type":"extras"},{"doc":"Bugfix: fix error when using atom form","ref":"changelog.html#1-0-1-2023-02-18","title":"CHANGELOG - 1.0.1 (2023-02-18)","type":"extras"},{"doc":"This version introduces the following breaking changes and new features: Rendering using a function component &lt;.live_select /&gt; instead of the old function style ( &lt;%= live_select ... %&gt; ) Dropping the message-based update cycle (which used handle_info/2 ) in favour of an event-based update cycle (which uses handle_event/3 ). This makes it much easier and more intuitive to use LiveSelect from another LiveComponent. Ability to customize the default rendering of dropdown entries and tags using the :option and :tag slots How to upgrade from version 0.x.x: Instead of rendering LiveSelect in this way: &lt;%= live_select form, field, mode: :tags %&gt; , render it in this way: &lt;.live_select form={form} field={field} mode={:tags} /&gt; Don't forget to add phx-target={@myself} if you're using LiveSelect from another LiveComponent Turn your handle_info/2 implementations into handle_event/3 : Turn this: def handle_info ( % ChangeMsg { } = change_msg , socket ) do options = retrieve_options ( change_msg . text ) send_update ( LiveSelect.Component , id : change_msg . id , options : options ) { :noreply , socket } end into: def handle_event ( &quot;live_select_change&quot; , %{ &quot;text&quot; =&gt; text , &quot;id&quot; =&gt; live_select_id } , socket ) do options = retrieve_options ( text ) send_update ( LiveSelect.Component , id : live_select_id , options : options ) { :noreply , socket } end If you're rendering LiveSelect in a LiveComponent, you can now place your handle_event/3 callback in the LiveComponent, there's no need to put the update logic in the view anymore","ref":"changelog.html#1-0-0-2023-02-15","title":"CHANGELOG - 1.0.0 (2023-02-15)","type":"extras"},{"doc":"Bugfix: component now works event when strict Content Security Policy are set","ref":"changelog.html#0-4-1-2023-02-07","title":"CHANGELOG - 0.4.1 (2023-02-07)","type":"extras"},{"doc":"add available_option_class configuration option to style options that have not been selected yet add user_defined_options configuration option to allow user to enter any tag enable assigning a custom id to the component enable programmatically clearing of the selection via clear assign add allow_clear configuration option. If set, an x button will appear next to the text input in single mode. Clicking the button clears the selection Deprecations LiveSelect.update_options/2 has been deprecated in favor of directly using Phoenix.LiveView.send_update/3","ref":"changelog.html#0-4-0-2023-01-30","title":"CHANGELOG - 0.4.0 (2023-01-30)","type":"extras"},{"doc":"set initial selection from the form or manually with value option set initial list of available options with options option add a max_selectable option to limit the maximum size of the selection","ref":"changelog.html#0-3-3-2023-01-15","title":"CHANGELOG - 0.3.3 (2023-01-15)","type":"extras"},{"doc":"Bugfix: options in dropdown not always clickable because of race condition with blur event ( https://github.com/maxmarcon/live_select/issues/7 )","ref":"changelog.html#0-3-2-2023-01-03","title":"CHANGELOG - 0.3.2 (2023-01-03)","type":"extras"},{"doc":"Bugfix: removed inputs_for because it was failing if the field is not an association","ref":"changelog.html#0-3-1-2022-12-15","title":"CHANGELOG - 0.3.1 (2022-12-15)","type":"extras"},{"doc":"tags mode hide dropdown on escape key pressed","ref":"changelog.html#0-3-0-2022-12-15","title":"CHANGELOG - 0.3.0 (2022-12-15)","type":"extras"},{"doc":"when disabled option is used, also disable hidden input style disabled text input in tailwind mode fix problem with selection via mouseclick when an input field is underneath the dropdown hide dropdown when user clicks away from component or input loses focus show dropdown when input obtains focus again using default black text in tailwind mode","ref":"changelog.html#0-2-1-2022-10-25","title":"CHANGELOG - 0.2.1 (2022-10-25)","type":"extras"},{"doc":"support for tailwind styles (now the default) more opinionated default styles ability to selectively remove classes from style defaults using the !class_name notation rename option search_term_min_length to update_min_len better error messages various improvements to the showcase app","ref":"changelog.html#0-2-0-2022-10-03","title":"CHANGELOG - 0.2.0 (2022-10-03)","type":"extras"},{"doc":"raise if class and extra_class options are used in invalid combinations ( https://github.com/maxmarcon/live_select/issues/2 ) Bugfixes route server events to the right live select component using the component id ( https://github.com/maxmarcon/live_select/issues/1 )","ref":"changelog.html#0-1-4-2022-09-20","title":"CHANGELOG - 0.1.4 (2022-09-20)","type":"extras"},{"doc":"rename LiveSelect.update/2 to LiveSelect.update_options/2 add debounce option add search delay option to showcase app JSON-encode option values before assigning them to the hidden input field add LiveSelect.ChangeMsg struct to be used as change message","ref":"changelog.html#0-1-3-2022-08-12","title":"CHANGELOG - 0.1.3 (2022-08-12)","type":"extras"},{"doc":"Disable input field via options Placeholder text via options Improve docs and showcase app Remove setting component id via options Bugfixes Use atoms as field names, because strings are not accepted by Ecto forms","ref":"changelog.html#0-1-2-2022-08-10","title":"CHANGELOG - 0.1.2 (2022-08-10)","type":"extras"},{"doc":"Remove all colors from default daisyui styles Improve styling of showcase app Improve docs Remove the msg_prefix option in favor of change_msg","ref":"changelog.html#0-1-1-2022-08-09","title":"CHANGELOG - 0.1.1 (2022-08-09)","type":"extras"},{"doc":"First version 🎉","ref":"changelog.html#0-1-0-2022-08-09","title":"CHANGELOG - 0.1.0 (2022-08-09)","type":"extras"}]